%global srcname engineio

# Sphinx-generated HTML documentation is not suitable for packaging; see
# https://bugzilla.redhat.com/show_bug.cgi?id=2006555 for discussion.
#
# We can generate PDF documentation as a lesser substitute.
%bcond_without doc_pdf

Name:           python-%{srcname}
Version:        3.14.2
Release:        3%{?dist}
Summary:        Python Engine.IO server and client

License:        MIT
URL:            https://github.com/miguelgrinberg/%{name}/
Source0:        %{url}/archive/v%{version}/%{name}-%{version}.tar.gz

BuildArch:      noarch
 
BuildRequires:  python3-devel
BuildRequires:  pyproject-rpm-macros

# Documentation
%if %{with doc_pdf}
BuildRequires:  make
BuildRequires:  python3dist(sphinx)
BuildRequires:  python3-sphinx-latex
BuildRequires:  latexmk
%endif

# Extra testing dependencies
BuildRequires:  python3dist(eventlet)
BuildRequires:  python3dist(pytest)
BuildRequires:  python3dist(tornado)

%global common_description %{expand:
Engine.IO is a lightweight transport protocol that enables real-time
bidirectional event-based communication between clients (typically, though not
always, web browsers) and a server. The official implementations of the client
and server components are written in JavaScript. This package provides Python
implementations of both, each with standard and asyncio variants.}

%description %{common_description}


%generate_buildrequires
%pyproject_buildrequires -x client,asyncio_client


%package -n     python3-%{srcname}
Summary:        %{summary}

%description -n python3-%{srcname} %{common_description}


%pyproject_extras_subpkg -n python3-%{srcname} client asyncio_client


%package        doc
Summary:        Documentation for %{name}

%description    doc %{common_description}


%prep
%autosetup -p1

# Remove pre-compiled/pre-minified browser build of
# https://github.com/socketio/engine.io from the examples. This makes them less
# useful, but satisfies
# https://docs.fedoraproject.org/en-US/packaging-guidelines/JavaScript/ and
# https://docs.fedoraproject.org/en-US/packaging-guidelines/#bundling. It
# doesn’t seem worth it to package the JavaScript implementation of Engine.IO
# just for the sake of these examples.
find examples -type f -name 'engine.io.js' -print -delete

# Find executable files without shebang lines, and fix their permissions
# https://github.com/miguelgrinberg/python-engineio/pull/240
find . -type f -perm /0111 |
  while read -r fn
  do
    if ! head "${fn}" | grep -E '^#!' >/dev/null
    then
      chmod -v a-x "${fn}"
    fi
  done


%build
%pyproject_wheel
%if %{with doc_pdf}
PYTHONPATH="${PWD}" %make_build -C docs latex SPHINXOPTS='%{?_smp_mflags}'
%make_build -C docs/_build/latex
%endif


%install
%pyproject_install
%pyproject_save_files %{srcname}


%check
# Test{AsyncServer,Client,Server}.test_logger are failing with:
#   AssertionError: 30 != 40
# This should be looked into more closely if it is not fixed in a later release.
%pytest -k 'not test_logger'


%files -n python3-%{srcname} -f %{pyproject_files}
%license LICENSE


%files doc
%license LICENSE
%doc CHANGES.md
%doc README.rst
%if %{with doc_pdf}
%doc docs/_build/latex/python-engineio.pdf
%endif
# Bundled pre-compiled engine.io.js has been removed:
%doc examples


%changelog
* Fri Oct 01 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 3.14.2-3
- Build PDF documentation instead of HTML

* Sun Jul 04 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 3.14.2-2
- Fix typos in script to remove executable permissions from files without
  shebangs

* Sun Jul 04 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 3.13.1-1
- Update to 3.14.2 (last 3.x release)
- Drop python-engineio-3.13.1-all-tasks.patch, now upstream
- Fix spurious executable permissions (upstream PR#240)
- Remove .buildinfo file from HTML documentation

* Thu Jul 01 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 3.13.1-5
- Near-total spec file rewrite
- Removed obsolete practices like python_provide macro and manual Requires
- Added documentation and tests

* Fri Jun 04 2021 Python Maint <python-maint@redhat.com> - 3.13.1-4
- Rebuilt for Python 3.10

* Wed Jan 27 2021 Fedora Release Engineering <releng@fedoraproject.org> - 3.13.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_34_Mass_Rebuild

* Sun Aug 09 2020 Mukundan Ragavan <nonamedotc@fedoraproject.org> - 3.13.2-1
- Disable tests temporarily (fixes FTBFS)

* Tue Aug 04 2020 Mukundan Ragavan <nonamedotc@fedoraproject.org> - 3.13.1-1
- Update to 3.13.1

* Sat Aug 01 2020 Fedora Release Engineering <releng@fedoraproject.org> - 3.11.1-6
- Second attempt - Rebuilt for
  https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Wed Jul 29 2020 Fedora Release Engineering <releng@fedoraproject.org> - 3.11.1-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Tue May 26 2020 Miro Hrončok <mhroncok@redhat.com> - 3.11.1-4
- Rebuilt for Python 3.9

* Thu Jan 30 2020 Fedora Release Engineering <releng@fedoraproject.org> - 3.11.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_32_Mass_Rebuild

* Mon Dec 30 2019 Mukundan Ragavan <nonamedotc@gmail.com> - 3.11.1-2
- Use expand macro for description

* Sun Dec 22 2019 Mukundan Ragavan <nonamedotc@gmail.com> - 3.11.1-1
- Initial package.
